// bath.pov
//
// (C) 2012 Sander de Jong
//
// render: 
//   povray +Ibath.pov +W640 +H480 +A +KC +KFF120
// convert to mp4: 
//   yes | ffmpeg -f image2 -i bath%03d.png -b 2048kb bath.mp4
// play:
//   mplayer bath.mp4 -loop 0

#include "colors.inc"

//
// Animation
//

#declare numsections = 4;
#declare section = floor( clock * numsections );

#declare ct_l  = clock * numsections - section;
#declare ct_lr = 1.0 - ct_l;
#declare ct_s  = sin(ct_l * 0.5 * pi);
#declare ct_sr = 1.0 - sin(ct_l * 0.5 * pi + 0.5 * pi);
#declare ct_q  = ct_l * ct_l;
#declare ct_qr = 1.0 - ct_l * ct_l; 


//
// Camera and lightsources
//

camera 
{
	location <-1.0, 1.5, -4.0>
	look_at <0, 0.5, 0>

#if (section = 0)
	rotate <0,0,0>
#end	
#if (section = 1)
	rotate <0,-40*ct_s,0>
#end
#if (section = 2)
	rotate <0,-40,0>
#end
#if (section = 3)
	rotate <0, -40 + 40*ct_s, 0>
#end
}

light_source
{
	<2, 4, -3>
	color White
}

light_source
{
	<-3, 6, -7>
	color rgb <0.4, 0.4, 0.4>
}


//
// Background color and fog
//

background 
{
	color White
}

fog 
{
	distance 30
	color rgb <0.7, 0.7, 0.7>
}


//
// The scene
//

plane 
{
    y, 0
    pigment {checker Green, White}
}

sphere
{
	<0, 0, 0>, 0.5
	pigment { color Red }
    finish 
    {
    	ambient .1
		diffuse .6
		specular .75
		roughness .001
        reflection { .3 }
	}
	translate <-1, 0.5, 0>
}

sphere
{
	<0, 0, 0>, 0.5
	pigment { color Yellow }
    finish 
    {
    	ambient .1
		diffuse .6
		specular .75
		roughness .001
        reflection { .3 }
	}
	translate <0, 0.5, 0>
}

sphere
{
	<0, 0, 0>, 0.5
	pigment { color Blue }
    finish 
    {
    	ambient .1
		diffuse .6
		specular .75
		roughness .001
        reflection { .3 }
	}
	translate <1, 0.5, 0>
}

merge
{
	torus
	{
		2, 0.025
	}

	difference
	{
		sphere
		{
			<0, 0, 0>, 2.025
		}
		sphere
		{
			<0, 0, 0>, 1.975
		}
		box
		{
			<-3, -3, -3>, <3, 0, 3>
		}
	}
	pigment { color rgb <0.75, 1.0, 0.75> filter 0.90 }
	interior { ior 1.5 }
	finish { ambient 0 diffuse 0.1}
#if (section = 0)
	rotate <45*ct_sr,0,0>
#end	
#if (section = 1)
	rotate <45+45*ct_s,0,0>
#end
#if (section = 2)
	rotate <90-90*ct_s,0,0>
#end
#if (section = 3)
	rotate <0, 0, 0>
#end
}


#declare WalkingBox = box
{
	<-1, 0, -0.05>, <0, 1, 0.05>
	rotate <0, 0, -90*ct_sr>
	translate <section, 0, 0>
}
	
#declare idx = 0;
#while (idx < 10)

	object
	{
		WalkingBox
		pigment { color Red }
		translate <-5*4+4*idx, 0, 3>
	}
  
  	#declare idx = idx + 1;
#end

